@@ -39,7 +39,7 @@
  *  USA.
  */
 
-#include <rfb/rfb.h>
+#include "rfb/rfb.h"
 
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -582,8 +582,7 @@ ListenOnTCPPort(rfbScreenInfoPtr rfbScreen, int port, const char *netIface)
 
   if(netIface == NULL || strlen(netIface) == 0)
   {
-#ifdef ENABLE_IPV6
-    int sock6 = -1;
+#ifdef VINO_ENABLE_IPV6
     struct sockaddr_in6 s6;
 
     memset(&s6, 0, sizeof(s6));
@@ -591,10 +590,10 @@ ListenOnTCPPort(rfbScreenInfoPtr rfbScreen, int port, const char *netIface)
     s6.sin6_port   = htons(port);
     s6.sin6_addr   = in6addr_any;
 
-    sock6 = NewSocketListenTCP ((struct sockaddr*)&s6, sizeof(s6));
-    rfbLog("Listening IPv6://[::]:%d\n", port);
+    sock = NewSocketListenTCP ((struct sockaddr*)&s6, sizeof(s6));
+    rfbLog("Listening IPv{4,6}://*:%d\n", port);
 #endif
-
+    if(sock < 0) {
       struct sockaddr_in s4;
 
       memset(&s4, 0, sizeof(s4));
@@ -604,23 +603,15 @@ ListenOnTCPPort(rfbScreenInfoPtr rfbScreen, int port, const char *netIface)
 
       sock = NewSocketListenTCP ((struct sockaddr*)&s4, sizeof(s4));
       rfbLog("Listening IPv4://0.0.0.0:%d\n", port);
-
-#ifdef ENABLE_IPV6
-    if(sock6 > 0) {
-       psock[*ptot] = sock6;
-      *ptot        += 1;
     }
-#endif
+
     if(sock > 0) {
-       psock[*ptot] = sock;
-      *ptot        += 1;
+      psock[0] = sock;
+     *ptot     = 1;
+      return TRUE;
     }
 
-    if (*ptot)
-      return TRUE;
-
-    /* no need to log sock/sock6, both are -1 here */
-    rfbLog("Problems in NewSocketListenTCP()\n");
+    rfbLog("Problems in NewSocketListenTCP(), sock=%d\n", sock);
     return FALSE;
   }
 
@@ -648,7 +639,7 @@ ListenOnTCPPort(rfbScreenInfoPtr rfbScreen, int port, const char *netIface)
         sock = NewSocketListenTCP((struct sockaddr*)s4, INET_ADDRSTRLEN);
       }
     }
-#ifdef ENABLE_IPV6            
+#ifdef VINO_ENABLE_IPV6
     if (ifa->ifa_addr->ADDR_FAMILY_MEMBER == AF_INET6) {
       struct sockaddr_in6 *s6 = (struct sockaddr_in6*)ifa->ifa_addr;
       s6->sin6_port           = htons(port);
@@ -690,15 +681,6 @@ NewSocketListenTCP(struct sockaddr *addr, socklen_t len)
       return -1;
     }
 
-#ifdef ENABLE_IPV6
-    if (addr->sa_family == AF_INET6) {
-#if defined(IPPROTO_IPV6) && defined(IPV6_V6ONLY)
-      setsockopt(sock, IPPROTO_IPV6, IPV6_V6ONLY, (char *)&one, sizeof(one));
-      /* we cannot really check for errors here */
-#endif
-    }
-#endif
-
     if (bind(sock, addr, len) < 0) {
       close(sock);
       return -1;
